@@ -158,6 +158,14 @@
 ;; The key parameter may be a list of keys, in which case the function
 ;; will do a nested insert, inserting trees inside values.
 (define* (aa-insert tree k #:optional v)
+"Insert a value into the tree and rebalance the tree (non-mutating). If
+a node with a matching key exists, replace it with the new node. Keys
+may be of any type, but any key inserted must be comparable to all
+keys already used in the tree. Comparable means have a goops method
+defined for < and equal?. Numbers, strings, identifiers, and keywords
+are supported by default. The key parameter may instead be a list of
+keys, in which case the function will do a nested insert, inserting
+trees inside values."
   (if (list? k)
       (aa-insert-nested tree k v)
       (split
@@ -169,6 +177,14 @@
          (#t (replace-right-tree tree (aa-insert (right-tree tree) k v))))))))
 
 (define (aa-search tree k)
+  "Searches for the node in the specified key, and returns
+the (wrapped) value of that node. If a node is found, the value will
+be returned wrapped in a single element list. If no such node is
+found, a #nil value will be returned.
+If a list of keys is provided instead of a single key, aa-search will
+attempt a nested tree search, starting the search with the first key
+in the list. If a nested tree of some required level does not exist,
+the function will simply return #nil."
   (if (list? k) (aa-search-nested tree k)
       (cond
        ((nil? tree) #nil)
@@ -181,13 +197,12 @@
 ;; The key parameter may be a list of keys, in which case the function
 ;; will do a nested delete.
 (define (aa-delete tree k)
-  "Performs a non-mutating delete on tree. Deletes the node in tree
-which has key key. If there is no such node, it simply returns
-tree. O(log n) worst case efficiency. If a list of keys is provided
-instead of a single key, aa-delete will attempt a nested tree delete,
-starting the search with the first key in the list. If a nested tree
-of some required level does not exist, it will simply return the
-original tree unmodified."
+"Deletes the node from tree with the specified key (non-mutating). If
+there is no such node, the unmodified tree is returned. If a list of
+keys is provided instead of a single key, aa-delete will attempt a
+nested tree delete, starting the search with the first key in the
+list, and deleting the final node found. If a node at some level is
+not found, the original unmodified tree will be returned."
   (if (list? k) (aa-delete-nested tree k)
       (let* ((t1
               (skew
@@ -241,10 +256,13 @@ original tree unmodified."
                                 (descend-right (right-tree t))))))
     (descend-right (left-tree tree))))
 
-(define (aa-map fn tree)
-  (if (left-tree tree) (aa-map fn (left-tree tree)))
-  (fn (key-value tree))
-  (if (right-tree tree) (aa-map fn (right-tree tree))))
+(define (aa-map proc tree)
+"Maps proc over the key-value pairs in tree, moving from smallest to
+greatest key, returning the list of results. proc must take an
+argument of the form (key . value). Does not return results."
+  (if (left-tree tree) (aa-map proc (left-tree tree)))
+  (proc (key-value tree))
+  (if (right-tree tree) (aa-map proc (right-tree tree))))
 
 (define (aa-map-reverse fn tree)
   (if (right-tree tree) (aa-map fn (right-tree tree)))
@@ -258,6 +276,8 @@ original tree unmodified."
   (aa-map (lambda (kv) (fn (cdr kv))) tree))
 
 (define (aa-to-list tree)
+"Return the key-value pairs of the tree in a list. Pairs are order by
+key from smallest to greatest."
   (let ((l '()))
     (aa-map-reverse
      (lambda (kv)
@@ -321,6 +341,14 @@ original tree unmodified."
           (aa-search-nested (car search-result) (cdr key-lst)))))))
 
 (define (list-to-aa-tree init-tree lst)
+"Takes keys and values from lst and inserts them into
+init-tree. Argument lst must be a list of the form (KEY VALUE KEY
+VALUE ...) with zero or more sets of keys and values.  If a VALUE is a
+list, then VALUE will be processed recursively by list-to-aa-tree,
+creating another tree stored as the value of that node (a nested
+tree). If you wish simply to store a list as a node value, use the
+identifer _ as the first element of the list. That _ will be removed
+before the node is added."
   (cond
    ((null? lst) init-tree)
    ((null? (cdr lst)) (throw 'missing-corresponding-value))
