@@ -175,6 +175,22 @@
       (aa-search tree1 (list 5 "b" 'e)))
   '(5))
 
+(test-equal
+    (let* ((tree1
+            (aa-insert
+             (aa-insert
+              (aa-insert #nil 3 "three") 1 "one")
+             5
+             (aa-insert
+              (aa-insert
+               (aa-insert #nil #:c 3) #:a 1)
+              #:b
+              (aa-insert
+               (aa-insert
+                (aa-insert #nil 'b 2) 'e 5) 'd 4)))))
+      (aa-search tree1 (list 5 #:b 'e)))
+  '(5))
+
 (test-equal
     (let* ((tree1
             (aa-insert
@@ -216,4 +232,14 @@
       (and (equal? (aa-search tree1 c1) '("head2"))
            (equal? (aa-search tree1 c2) '("tail1"))))))
 
+(test-equal
+    (let ((tree1
+           (list-to-aa-tree #nil
+            '(#:e 3
+                  #:f
+                  ("d" 5
+                   "b" (_ foo bar))))))
+      (aa-search tree1 '(#:f "b")))
+  '((foo bar)))
+
 (test-end "test-aa-tree")
